@@ -3,7 +3,6 @@
 // Copyright (c) Contributors to the OpenEXR Project.
 //
 
-
 #ifndef INCLUDED_IMF_OPAQUE_ATTRIBUTE_H
 #define INCLUDED_IMF_OPAQUE_ATTRIBUTE_H
 
@@ -22,64 +21,55 @@
 #include "ImfExport.h"
 #include "ImfNamespace.h"
 
-#include "ImfAttribute.h"
 #include "ImfArray.h"
+#include "ImfAttribute.h"
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
 
-
-class IMF_EXPORT_TYPE OpaqueAttribute: public Attribute
+class IMF_EXPORT_TYPE OpaqueAttribute : public Attribute
 {
-  public:
-
+public:
     //----------------------------
     // Constructors and destructor
     //----------------------------
 
     IMF_EXPORT OpaqueAttribute (const char typeName[]);
-    IMF_EXPORT OpaqueAttribute (const OpaqueAttribute &other);
+    IMF_EXPORT OpaqueAttribute (const OpaqueAttribute& other);
     IMF_EXPORT virtual ~OpaqueAttribute ();
 
-
     //-------------------------------
     // Get this attribute's type name
     //-------------------------------
 
-    IMF_EXPORT virtual const char *	typeName () const;
-    
+    IMF_EXPORT virtual const char* typeName () const;
 
     //------------------------------
     // Make a copy of this attribute
     //------------------------------
 
-    IMF_EXPORT virtual Attribute *		copy () const;
-
+    IMF_EXPORT virtual Attribute* copy () const;
 
     //----------------
     // I/O and copying
     //----------------
 
-    IMF_EXPORT virtual void		writeValueTo (OPENEXR_IMF_INTERNAL_NAMESPACE::OStream &os,
-                                              int version) const;
+    IMF_EXPORT virtual void writeValueTo (
+        OPENEXR_IMF_INTERNAL_NAMESPACE::OStream& os, int version) const;
 
-    IMF_EXPORT virtual void		readValueFrom (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is,
-                                               int size,
-                                               int version);
+    IMF_EXPORT virtual void readValueFrom (
+        OPENEXR_IMF_INTERNAL_NAMESPACE::IStream& is, int size, int version);
 
-    IMF_EXPORT virtual void		copyValueFrom (const Attribute &other);
+    IMF_EXPORT virtual void copyValueFrom (const Attribute& other);
 
+    int                dataSize () const { return _dataSize; }
+    const Array<char>& data () const { return _data; }
 
-    int                         dataSize() const { return _dataSize; }
-    const Array<char>&          data() const { return _data; }
-        
-  private:
-
-    std::string			_typeName;
-    long			_dataSize;
-    Array<char>			_data;
+private:
+    std::string _typeName;
+    long        _dataSize;
+    Array<char> _data;
 };
 
-
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_EXIT
 
 #endif
