@@ -14,8 +14,10 @@
 extern "C" {
 #endif
 
+/** @file */
+
 /** 
- * @defgroup PartInfo Part related definitions
+ * @defgroup PartInfo Part related definitions.
  *
  * A part is a separate entity in the OpenEXR file. This was
  * formalized in the OpenEXR 2.0 timeframe to allow there to be a
@@ -35,22 +37,22 @@ extern "C" {
  * @{
  */
 
-/** @brief Query how many parts are in the file */
+/** @brief Query how many parts are in the file. */
 EXR_EXPORT exr_result_t exr_get_count (exr_const_context_t ctxt, int* count);
 
-/** @brief Query the part name for the specified part
+/** @brief Query the part name for the specified part.
  *
  * NB: If this file is a single part file and name has not been set, this
- * will return NULL.
+ * will return `NULL`.
  */
 EXR_EXPORT exr_result_t
 exr_get_name (exr_const_context_t ctxt, int part_index, const char** out);
 
-/** @brief Query the storage type for the specified part */
+/** @brief Query the storage type for the specified part. */
 EXR_EXPORT exr_result_t
 exr_get_storage (exr_const_context_t ctxt, int part_index, exr_storage_t* out);
 
-/** @brief Define a new part in the file */
+/** @brief Define a new part in the file. */
 EXR_EXPORT exr_result_t exr_add_part (
     exr_context_t ctxt,
     const char*   partname,
@@ -64,7 +66,7 @@ EXR_EXPORT exr_result_t exr_add_part (
  * Return `ERR_SUCCESS` on success, an error otherwise (i.e. if the part
  * is not tiled).
  *
- * It is valid to pass NULL to either of the @p levelsx or @p levelsy
+ * It is valid to pass `NULL` to either of the @p levelsx or @p levelsy
  * arguments, which enables testing if this part is a tiled part, or
  * if you don't need both (i.e. in the case of a mip-level tiled
  * image)
@@ -75,15 +77,15 @@ EXR_EXPORT exr_result_t exr_get_tile_levels (
     int32_t*            levelsx,
     int32_t*            levelsy);
 
-/** @brief Query the tile size for a particular level in the specified part
+/** @brief Query the tile size for a particular level in the specified part.
  *
  * If the part is a tiled part, fill in the tile size for the
- * specified part / level.
+ * specified part/level.
  *
- * Return `ERR_SUCCESS` on `success`, an error otherwise (i.e. if the
+ * Return `ERR_SUCCESS` on success, an error otherwise (i.e. if the
  * part is not tiled).
  *
- * It is valid to pass NULL to either of the @p tilew or @p tileh
+ * It is valid to pass `NULL` to either of the @p tilew or @p tileh
  * arguments, which enables testing if this part is a tiled part, or
  * if you don't need both (i.e. in the case of a mip-level tiled
  * image)
@@ -96,17 +98,17 @@ EXR_EXPORT exr_result_t exr_get_tile_sizes (
     int32_t*            tilew,
     int32_t*            tileh);
 
-/** @brief Query the data sizes for a particular level in the specified part
+/** @brief Query the data sizes for a particular level in the specified part.
  *
- * If the part is a tiled part, fill in the width / height for the
+ * If the part is a tiled part, fill in the width/height for the
  * specified levels.
  *
  * Return `ERR_SUCCESS` on success, an error otherwise (i.e. if the part
- * is not tiled)
+ * is not tiled).
  *
- * It is valid to pass NULL to either of the @p levw or @p levh
+ * It is valid to pass `NULL` to either of the @p levw or @p levh
  * arguments, which enables testing if this part is a tiled part, or
- * if you don't need both for some reason
+ * if you don't need both for some reason.
  */
 EXR_EXPORT exr_result_t exr_get_level_sizes (
     exr_const_context_t ctxt,
@@ -116,7 +118,7 @@ EXR_EXPORT exr_result_t exr_get_level_sizes (
     int32_t*            levw,
     int32_t*            levh);
 
-/** Return the number of chunks contained in this part of the file
+/** Return the number of chunks contained in this part of the file.
  *
  * As in the technical documentation for OpenEXR, the chunk is the
  * generic term for a pixel data block. This is the atomic unit that
@@ -125,13 +127,13 @@ EXR_EXPORT exr_result_t exr_get_level_sizes (
  * This should be used as a basis for splitting up how a file is
  * processed. Depending on the compression, a different number of
  * scanlines are encoded in each chunk, and since those need to be
- * encoded / decoded as a block, the chunk should be the basis for I/O
+ * encoded/decoded as a block, the chunk should be the basis for I/O
  * as well.
  */
 EXR_EXPORT exr_result_t
 exr_get_chunk_count (exr_const_context_t ctxt, int part_index, int32_t* out);
 
-/** Return the number of scanlines chunks for this file part
+/** Return the number of scanlines chunks for this file part.
  *
  * When iterating over a scanline file, this may be an easier metric
  * for multi-threading or other access than only negotiating chunk
@@ -140,7 +142,7 @@ exr_get_chunk_count (exr_const_context_t ctxt, int part_index, int32_t* out);
 EXR_EXPORT exr_result_t exr_get_scanlines_per_chunk (
     exr_const_context_t ctxt, int part_index, int32_t* out);
 
-/** Return the maximum unpacked size of a chunk for the file part
+/** Return the maximum unpacked size of a chunk for the file part.
  *
  * This may be used ahead of any actual reading of data, so can be
  * used to pre-allocate buffers for multiple threads in one block or
@@ -149,54 +151,100 @@ EXR_EXPORT exr_result_t exr_get_scanlines_per_chunk (
 EXR_EXPORT exr_result_t exr_get_chunk_unpacked_size (
     exr_const_context_t ctxt, int part_index, uint64_t* out);
 
+/** @brief Retrieve the zip compression level used for the specified part.
+ *
+ * This only applies when the compression method involves using zip
+ * compression (zip, zips, some modes of DWAA/DWAB).
+ *
+ * This value is NOT persisted in the file, and only exists for the
+ * lifetime of the context, so will be at the default value when just
+ * reading a file.
+ */
+EXR_EXPORT exr_result_t exr_get_zip_compression_level (
+    exr_const_context_t ctxt, int part_index, int* level);
+
+/** @brief Set the zip compression method used for the specified part.
+ *
+ * This only applies when the compression method involves using zip
+ * compression (zip, zips, some modes of DWAA/DWAB).
+ *
+ * This value is NOT persisted in the file, and only exists for the
+ * lifetime of the context, so this value will be ignored when
+ * reading a file.
+ */
+EXR_EXPORT exr_result_t
+exr_set_zip_compression_level (exr_context_t ctxt, int part_index, int level);
+
+/** @brief Retrieve the dwa compression level used for the specified part.
+ *
+ * This only applies when the compression method is DWAA/DWAB.
+ *
+ * This value is NOT persisted in the file, and only exists for the
+ * lifetime of the context, so will be at the default value when just
+ * reading a file.
+ */
+EXR_EXPORT exr_result_t exr_get_dwa_compression_level (
+    exr_const_context_t ctxt, int part_index, float* level);
+
+/** @brief Set the dwa compression method used for the specified part.
+ *
+ * This only applies when the compression method is DWAA/DWAB.
+ *
+ * This value is NOT persisted in the file, and only exists for the
+ * lifetime of the context, so this value will be ignored when
+ * reading a file.
+ */
+EXR_EXPORT exr_result_t
+exr_set_dwa_compression_level (exr_context_t ctxt, int part_index, float level);
+
 /**************************************/
 
-/** @defgroup PartMetadata Functions to get and set metadata for a particular part
+/** @defgroup PartMetadata Functions to get and set metadata for a particular part.
  * @{
  *
  */
 
-/** @brief Query the count of attributes in a part */
+/** @brief Query the count of attributes in a part. */
 EXR_EXPORT exr_result_t exr_get_attribute_count (
     exr_const_context_t ctxt, int part_index, int32_t* count);
 
-enum exr_attr_list_access_mode
+typedef enum exr_attr_list_access_mode
 {
-    EXR_ATTR_LIST_FILE_ORDER,  /**< order they appear in the file */
-    EXR_ATTR_LIST_SORTED_ORDER /**< alphabetically sorted */
-};
+    EXR_ATTR_LIST_FILE_ORDER,  /**< Order they appear in the file */
+    EXR_ATTR_LIST_SORTED_ORDER /**< Alphabetically sorted */
+} exr_attr_list_access_mode_t;
 
-/** @brief Query a particular attribute by index */
+/** @brief Query a particular attribute by index. */
 EXR_EXPORT exr_result_t exr_get_attribute_by_index (
-    exr_const_context_t            ctxt,
-    int                            part_index,
-    enum exr_attr_list_access_mode mode,
-    int32_t                        idx,
-    const exr_attribute_t**        outattr);
+    exr_const_context_t         ctxt,
+    int                         part_index,
+    exr_attr_list_access_mode_t mode,
+    int32_t                     idx,
+    const exr_attribute_t**     outattr);
 
-/** @brief Query a particular attribute by name */
+/** @brief Query a particular attribute by name. */
 EXR_EXPORT exr_result_t exr_get_attribute_by_name (
     exr_const_context_t     ctxt,
     int                     part_index,
     const char*             name,
     const exr_attribute_t** outattr);
 
-/** @brief Query the list of attributes in a part
+/** @brief Query the list of attributes in a part.
  *
  * This retrieves a list of attributes currently defined in a part.
  *
- * If outlist is NULL, this function still succeeds, filling only the
+ * If outlist is `NULL`, this function still succeeds, filling only the
  * count. In this manner, the user can allocate memory for the list of
  * attributes, then re-call this function to get the full list.
  */
 EXR_EXPORT exr_result_t exr_get_attribute_list (
-    exr_const_context_t            ctxt,
-    int                            part_index,
-    enum exr_attr_list_access_mode mode,
-    int32_t*                       count,
-    const exr_attribute_t**        outlist);
+    exr_const_context_t         ctxt,
+    int                         part_index,
+    exr_attr_list_access_mode_t mode,
+    int32_t*                    count,
+    const exr_attribute_t**     outlist);
 
-/** Declare an attribute within the specified part
+/** Declare an attribute within the specified part.
  *
  * Only valid when a file is opened for write.
  */
@@ -207,7 +255,7 @@ EXR_EXPORT exr_result_t exr_attr_declare_by_type (
     const char*       type,
     exr_attribute_t** newattr);
 
-/** @brief Declare an attribute within the specified part
+/** @brief Declare an attribute within the specified part.
  *
  * Only valid when a file is opened for write.
  */
@@ -227,7 +275,7 @@ EXR_EXPORT exr_result_t exr_attr_declare (
  * @{
  */
 
-/** @brief Initialize all required attributes for all files
+/** @brief Initialize all required attributes for all files.
  *
  * NB: other file types do require other attributes, such as the tile
  * description for a tiled file.
@@ -260,7 +308,7 @@ EXR_EXPORT exr_result_t exr_initialize_required_attr_simple (
     int32_t           height,
     exr_compression_t ctype);
 
-/** @brief Copy the attributes from one part to another
+/** @brief Copy the attributes from one part to another.
  *
  * This allows one to quickly unassigned attributes from one source to another.
  *
@@ -279,16 +327,16 @@ EXR_EXPORT exr_result_t exr_copy_unset_attributes (
     exr_const_context_t source,
     int                 src_part_index);
 
-/** @brief Retrieve the list of channels */
+/** @brief Retrieve the list of channels. */
 EXR_EXPORT exr_result_t exr_get_channels (
     exr_const_context_t ctxt, int part_index, const exr_attr_chlist_t** chlist);
 
-/** @brief Define a new channel to the output file part
+/** @brief Define a new channel to the output file part.
  *
  * The @p percept parameter is used for lossy compression techniques
  * to indicate that the value represented is closer to linear (1) or
  * closer to logarithmic (0). For r, g, b, luminance, this is normally
- * 0
+ * 0.
  */
 EXR_EXPORT int exr_add_channel (
     exr_context_t              ctxt,
@@ -299,64 +347,64 @@ EXR_EXPORT int exr_add_channel (
     int32_t                    xsamp,
     int32_t                    ysamp);
 
-/** @brief Copy the channels from another source
+/** @brief Copy the channels from another source.
  *
  * Useful if you are manually constructing the list or simply copying
- * from an input file
+ * from an input file.
  */
 EXR_EXPORT exr_result_t exr_set_channels (
     exr_context_t ctxt, int part_index, const exr_attr_chlist_t* channels);
 
-/** @brief Retrieve the compression method used for the specified part */
+/** @brief Retrieve the compression method used for the specified part. */
 EXR_EXPORT exr_result_t exr_get_compression (
     exr_const_context_t ctxt, int part_index, exr_compression_t* compression);
-/** @brief Set the compression method used for the specified part */
+/** @brief Set the compression method used for the specified part. */
 EXR_EXPORT exr_result_t exr_set_compression (
     exr_context_t ctxt, int part_index, exr_compression_t ctype);
 
-/** @brief Retrieve the data window for the specified part */
+/** @brief Retrieve the data window for the specified part. */
 EXR_EXPORT exr_result_t exr_get_data_window (
     exr_const_context_t ctxt, int part_index, exr_attr_box2i_t* out);
-/** @brief Set the data window for the specified part */
+/** @brief Set the data window for the specified part. */
 EXR_EXPORT int exr_set_data_window (
     exr_context_t ctxt, int part_index, const exr_attr_box2i_t* dw);
 
-/** @brief Retrieve the display window for the specified part */
+/** @brief Retrieve the display window for the specified part. */
 EXR_EXPORT exr_result_t exr_get_display_window (
     exr_const_context_t ctxt, int part_index, exr_attr_box2i_t* out);
-/** @brief Set the display window for the specified part */
+/** @brief Set the display window for the specified part. */
 EXR_EXPORT int exr_set_display_window (
     exr_context_t ctxt, int part_index, const exr_attr_box2i_t* dw);
 
-/** @brief Retrieve the line order for storing data in the specified part (use 0 for single part images) */
+/** @brief Retrieve the line order for storing data in the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_get_lineorder (
     exr_const_context_t ctxt, int part_index, exr_lineorder_t* out);
-/** @brief Set the line order for storing data in the specified part (use 0 for single part images) */
+/** @brief Set the line order for storing data in the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t
 exr_set_lineorder (exr_context_t ctxt, int part_index, exr_lineorder_t lo);
 
 /** @brief Retrieve the pixel aspect ratio for the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_get_pixel_aspect_ratio (
     exr_const_context_t ctxt, int part_index, float* par);
-/** @brief Set the pixel aspect ratio for the specified part (use 0 for single part images) */
+/** @brief Set the pixel aspect ratio for the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t
 exr_set_pixel_aspect_ratio (exr_context_t ctxt, int part_index, float par);
 
-/** @brief Retrieve the screen oriented window center for the specified part (use 0 for single part images) */
+/** @brief Retrieve the screen oriented window center for the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_get_screen_window_center (
     exr_const_context_t ctxt, int part_index, exr_attr_v2f_t* wc);
-/** @brief Set the screen oriented window center for the specified part (use 0 for single part images) */
+/** @brief Set the screen oriented window center for the specified part (use 0 for single part images). */
 EXR_EXPORT int exr_set_screen_window_center (
     exr_context_t ctxt, int part_index, const exr_attr_v2f_t* wc);
 
-/** @brief Retrieve the screen oriented window width for the specified part (use 0 for single part images) */
+/** @brief Retrieve the screen oriented window width for the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_get_screen_window_width (
     exr_const_context_t ctxt, int part_index, float* out);
-/** @brief Set the screen oriented window width for the specified part (use 0 for single part images) */
+/** @brief Set the screen oriented window width for the specified part (use 0 for single part images). */
 EXR_EXPORT exr_result_t
 exr_set_screen_window_width (exr_context_t ctxt, int part_index, float ssw);
 
-/** @brief Retrieve the tiling info for a tiled part (use 0 for single part images) */
+/** @brief Retrieve the tiling info for a tiled part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_get_tile_descriptor (
     exr_const_context_t    ctxt,
     int                    part_index,
@@ -365,7 +413,7 @@ EXR_EXPORT exr_result_t exr_get_tile_descriptor (
     exr_tile_level_mode_t* level,
     exr_tile_round_mode_t* round);
 
-/** @brief Set the tiling info for a tiled part (use 0 for single part images) */
+/** @brief Set the tiling info for a tiled part (use 0 for single part images). */
 EXR_EXPORT exr_result_t exr_set_tile_descriptor (
     exr_context_t         ctxt,
     int                   part_index,
@@ -386,7 +434,7 @@ exr_set_version (exr_context_t ctxt, int part_index, int32_t val);
 EXR_EXPORT exr_result_t
 exr_set_chunk_count (exr_context_t ctxt, int part_index, int32_t val);
 
-/** @} */ /* required attr group */
+/** @} */ /* required attr group. */
 
 /** 
  * @defgroup BuiltinAttributeHelpers Attribute utilities for builtin types
@@ -420,7 +468,7 @@ EXR_EXPORT exr_result_t exr_attr_set_box2f (
     const char*             name,
     const exr_attr_box2f_t* val);
 
-/** @brief Zero-copy query of channel data
+/** @brief Zero-copy query of channel data.
  *
  * Do not free or manipulate the @p chlist data, or use
  * after the lifetime of the context.
@@ -432,7 +480,7 @@ EXR_EXPORT exr_result_t exr_attr_get_channels (
     const exr_attr_chlist_t** chlist);
 
 /** @brief This allows one to quickly copy the channels from one file
- * to another
+ * to another.
  */
 EXR_EXPORT exr_result_t exr_attr_set_channels (
     exr_context_t            ctxt,
@@ -485,7 +533,7 @@ EXR_EXPORT exr_result_t exr_attr_get_float (
 EXR_EXPORT exr_result_t exr_attr_set_float (
     exr_context_t ctxt, int part_index, const char* name, float val);
 
-/** @brief Zero-copy query of float data
+/** @brief Zero-copy query of float data.
  *
  * Do not free or manipulate the @p out data, or use after the
  * lifetime of the context.
@@ -603,7 +651,7 @@ EXR_EXPORT exr_result_t exr_attr_set_rational (
     const char*                name,
     const exr_attr_rational_t* r);
 
-/** @brief Zero-copy query of string value
+/** @brief Zero-copy query of string value.
  *
  * Do not modify the string pointed to by @p out, and do not use
  * after the lifetime of the context.
@@ -618,13 +666,13 @@ EXR_EXPORT exr_result_t exr_attr_get_string (
 EXR_EXPORT exr_result_t exr_attr_set_string (
     exr_context_t ctxt, int part_index, const char* name, const char* s);
 
-/** @brief Zero-copy query of string data
+/** @brief Zero-copy query of string data.
  *
  * Do not free the strings pointed to by the array.
  *
  * Must provide @p size.
  *
- * @param out must be a ``const char**`` array large enough to hold
+ * \p out must be a ``const char**`` array large enough to hold
  * the string pointers for the string vector when provided.
  */
 EXR_EXPORT exr_result_t exr_attr_get_string_vector (
